==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/functions/account/set_contact_sign_up_notification.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class SetContactSignUpNotification(Object):
    """Attributes:
        ID: ``0xcff43f61``

    Args:
        silent: ``bool``

    Raises:
        :obj:`RPCError <pyrogram.RPCError>`

    Returns:
        ``bool``
    """

    __slots__ = ["silent"]

    ID = 0xcff43f61
    QUALNAME = "account.SetContactSignUpNotification"

    def __init__(self, *, silent: bool):
        self.silent = silent  # Bool

    @staticmethod
    def read(b: BytesIO, *args) -> "SetContactSignUpNotification":
        # No flags
        
        silent = Bool.read(b)
        
        return SetContactSignUpNotification(silent=silent)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Bool(self.silent))
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/functions/account/set_contact_sign_up_notification.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class SetContactSignUpNotification(Object):
    """Attributes:
        ID: ``0xcff43f61``

    Parameters:
        silent: ``bool``

    Returns:
        ``bool``
    """

    __slots__ = ["silent"]

    ID = 0xcff43f61
    QUALNAME = "functions.account.SetContactSignUpNotification"

    def __init__(self, *, silent: bool):
        self.silent = silent  # Bool

    @staticmethod
    def read(b: BytesIO, *args) -> "SetContactSignUpNotification":
        # No flags
        
        silent = Bool.read(b)
        
        return SetContactSignUpNotification(silent=silent)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Bool(self.silent))
        
        return b.getvalue()
